pub struct ClientBuilder { /* private fields */ }Expand description
Builder wrapper for WebTransportOptions.
Implementations
Sourceimpl ClientBuilder
impl ClientBuilder
pub fn new() -> Self
Sourcepub fn with_pooling(self, val: bool) -> Self
pub fn with_pooling(self, val: bool) -> Self
Control whether the client/server is allowed to pool connections. In practice, keep this disabled unless you have a specific need.
Sourcepub fn with_unreliable(self, val: bool) -> Self
pub fn with_unreliable(self, val: bool) -> Self
true if QUIC is required, false if TCP is an acceptable fallback.
Sourcepub fn with_congestion_control(self, control: CongestionControl) -> Self
pub fn with_congestion_control(self, control: CongestionControl) -> Self
Hint at the desired congestion control algorithm.
Sourcepub fn with_server_certificate_hashes(self, hashes: Vec<Vec<u8>>) -> Client
pub fn with_server_certificate_hashes(self, hashes: Vec<Vec<u8>>) -> Client
Supply SHA-256 hashes for accepted certificates instead of using a root CA.
pub fn with_system_roots(self) -> Client