RecvStream

Struct RecvStream 

pub struct RecvStream { /* private fields */ }
A byte stream received from the remote peer.

Either side may close with an error code, or the peer may close with a FIN.

Implementations

Source

impl RecvStream

pub async fn read(&mut self, max: usize) -> Result<Option<Bytes>, Error>

Read the next chunk of data with the provided maximum size.

This returns a chunk of data instead of copying, which can be more efficient.

pub async fn read_buf<B: BufMut>( &mut self, buf: &mut B, ) -> Result<Option<usize>, Error>

Read some data into the provided buffer.

Returns the (non-zero) number of bytes read, or None if the stream is closed. Advances the buffer by the number of bytes read.

pub fn stop(&mut self, reason: &str)

Abort reading from the stream with the given reason.

pub async fn closed(&self) -> Result<Option<u8>, Error>

Block until the stream has closed and return the error code, if any.