SendStream

Struct SendStream 

pub struct SendStream { /* private fields */ }
A byte stream sent to the remote peer.

Implementations

Source

impl SendStream

pub async fn write(&mut self, buf: &[u8]) -> Result<(), Error>

Write all of the provided bytes to the stream.

pub async fn write_buf<B: Buf>(&mut self, buf: &mut B) -> Result<usize, Error>

Write some of the provided buffer to the stream.

pub fn reset(&mut self, reason: &str)

Send an immediate reset, closing the stream with an error.

pub fn finish(&mut self) -> Result<(), Error>

Mark the stream as finished.

This is called on drop, but can also be invoked manually.

pub fn set_priority(&mut self, priority: i32)

Set the stream’s priority.

Streams with higher values are sent first, but delivery order is not guaranteed.

pub async fn closed(&self) -> Result<Option<u8>, Error>

Block until the stream has closed and return the error code, if any.