Session

Struct Session 

pub struct Session { /* private fields */ }
A session represents a client-to-server connection.

This is the main entry point for creating streams and sending datagrams. Either endpoint may close the session with an error code and reason.

The session can be cloned to create multiple handles. However, handles cannot currently accept or open the same stream type.

Implementations

Source

impl Session

pub fn new(inner: WebTransport, url: Url) -> Self

pub async fn accept_uni(&self) -> Result<RecvStream, Error>

Accept a new unidirectional stream from the peer.

pub async fn accept_bi(&self) -> Result<(SendStream, RecvStream), Error>

Accept a new bidirectional stream from the peer.

pub async fn open_bi(&self) -> Result<(SendStream, RecvStream), Error>

Create a new bidirectional stream.

pub async fn open_uni(&self) -> Result<SendStream, Error>

Create a new unidirectional stream.

pub async fn send_datagram(&self, payload: Bytes) -> Result<(), Error>

Send a datagram over the network.

pub async fn recv_datagram(&self) -> Result<Bytes, Error>

Receive a datagram over the network.

pub fn close(&self, code: u32, reason: &str)

Close the session with the given error code and reason.

pub async fn closed(&self) -> Error

Block until the session closes and return the error.

pub fn url(&self) -> &Url

Return the URL used to create the session.