pub struct RecvStream { /* private fields */ }Expand description
A byte stream received from the remote peer.
Either side may close with an error code, or the peer may close with a FIN.
Implementations
Sourceimpl RecvStream
impl RecvStream
Sourcepub async fn read(&mut self, max: usize) -> Result<Option<Bytes>, Error>
pub async fn read(&mut self, max: usize) -> Result<Option<Bytes>, Error>
Read the next chunk of data with the provided maximum size.
This returns a chunk of data instead of copying, which can be more efficient.